<?php
require_once 'RentalAction.php';

class RentalCompany {

    /**
     * Fahrzeuge, die vermietet werden knnen
     *
     * @var array
     */
    protected $fleet = array();

    /**
     * Leihvorgnge
     *
     * @var array
     */
    protected $rentalActions = array();
    
    /**
     * Fgt ein neues Fahrzeug der Flotte hinzu
     *
     * @param string  $id
     * @param Vehicle $vehicle
     */
    public function addToFleet($id, Vehicle $vehicle) {
        $this->fleet[$id]  = $vehicle;
    }

    /**
     * Leiht ein Fahrzeug aus
     *
     * @param Vehicle $vehicle
     * @param Customer $customer
     * @return RentalAction
     */
    public function rentVehicle(Vehicle $vehicle, Customer $customer) {
        $vehicleId = array_search($vehicle, $this->fleet);
        if ($vehicleId === false) {
        	throw new UnknownVehicleException();
        }
        if (!$this->isVehicleAvailable($vehicle)) {
        	throw new VehicleNotAvailableException();
        }
        $rentalAction = new RentalAction($vehicle, $customer);
        $this->rentalActions[] = $rentalAction;
        
        return $rentalAction;
    }

    /**
     * Gibt ein Fahrzeug zurck
     *
     * @param Vehicle $vehicle
     * @return boolean
     */
    public function returnVehicle(Vehicle $vehicle) {
        foreach ($this->rentalActions as $rentalAction) {
        	if ($rentalAction->getVehicle() !== $vehicle) {
        		continue;
        	}
        	if ($rentalAction->isReturned()) {
        		continue;
        	}
        	$rentalAction->markVehicleReturned();
        	return true;
        }
        return false;
    }

    /**
     * berprft, ob ein Fahrzeug gerade ausgeliehen werden kann
     *
     * @param Vehicle $vehicle
     * @return boolean
     */
    public function isVehicleAvailable(Vehicle $vehicle) {
        foreach ($this->rentalActions as $rentalAction) {
        	if ($rentalAction->getVehicle() !== $vehicle) {
        		continue;
        	}
        	if ($rentalAction->isReturned()) {
        		continue;
        	}
        	return false;
        }
        return true;
    }
}
?>